﻿version
6.50
-1
0
Sub designer
end sub
@EndOfDesignText@
'version: 1.1
' the plugin script can communicate with the host by the following
' ----------------------------------------------------------------
' file access, all paths are rooted at AppPath so the same code works on desktop and device
'   CallHost("ReadFile", "SrcPath,DestScriptVarName")
'   CallHost("WriteFile", "DestPath,SrcScriptVarName")
'   CallHost("FileDel", "DestPath")
'   CallHost("FileExist", "DestPath,DestScriptVarName")
'   CallHost("DirCreate", "DestPath,SrcScriptVarName")
'   CallHost("DirDel", "DestPath")
'   CallHost("DirExist", "DestPath,DestScriptVarName")
' host data access
'   CallHost("GetArray", "SrcHostArrayName,DestScriptArrayName")
'   CallHost("SetArray", "DestHostArrayName,SrcScriptArrayName")
'   CallHost("GetVariable", "SrcHostVarName,DestScriptVarName")
'   CallHost("SetVariable", "DestHostVarName,SrcScriptVarName")
' invoke a Sub on the host and get the return value to a script variable
'   CallHost("CallSub", "Sub,Parameter1,...,DestScriptVarName")
' send arbitrary messages to the host
'   MsgBox(message, title)
'   Print whatever, something
' find out if it is running on a separate thread
'   CallHost("Threaded", "DestScriptVarName")
'
' the host communicates with the plugin by the following
' ------------------------------------------------------
' the host must call Initialise in this module
' the host must set Script.Args if necessary then call Script.Run
' the host must implement the following in this module
' a) subs whose names and parameters are known to the script writer
'    in this case Params0 ... Params3
' b) arrays and data whose names are known to the script writer
'      in this case Array0 ... Array3, Var0 ... Var3
' c) two subs called to transfer the known data that must get/set Script.DataVariable
'      GetArraySub - parameters(HostArrayName) : no return 	
'      SetArraySub - parameters(HostArrayName)) : no return 
' d) two subs called to transfer the known array data that must get/set Script.DataArray()
'      GetVariableSub - parameters(HostVariableName) : no return 	
'      SetVariableSub - parameters(HostVariableName) : no return 
' e) a sub called by MsgBox or Print in a script
'      MessageSub - parameters (message, title) : no return
' f) a sub called when the script ended for whatever reason
'      EndedSub - parameters(error, errordata) : no return

Sub Globals
	'Declare the global variables here.
	
	Public Args(0) ' passed as arguments to a script
	
	' single dimensional array data accessed by the running script and the host
	Public Array0(0)
	Public Array1(0)
	Public Array2(0)
	Public Array3(0)
	
	' variable data accessed by the running script and the host
	Public Var0
	Public Var1
	Public Var2
	Public Var3
End Sub

#Region Subs that are called by the host program to control the Script module

Public Sub Initialise
	' used as the module prefix for alll script Subs
	Script.SubModule = "Plugin"	
	' called by MsgBox in a script
	Script.MessageSub = "ShowMessage" ' takes two  parameters (message, title)	
	' called when a script ends
	Script.EndedSub = "Ended" ' parameter(error, errordata) : no return 
	' get and set host array
	Script.GetArraySub = "GetArray" ' parameter(HostArrayName) : no return 	
	Script.SetArraySub = "SetArray" ' parameter(HostArrayName) : no return 
	' get and set host variable
	Script.GetVariableSub = "GetVar" ' parameter(HostVariableName) : no return 	
	Script.SetVariableSub = "SetVar" ' parameter(HostVariableName) : no return 
End Sub

' runs the script given as a string with script lines separated by CRLF
' if runonthread is True then the script is run on a separate thread to the main thread
Public Sub Run(script, runonthread)
	Script.Args() = Args()
	Script.Run(script, runonthread)
End Sub

' return true if the script is running on a separate thread
Public Sub Running
	Return Script.Executing
End Sub

#End Region

#Region Subs defined by the host program that can be called from the running script

' these Subs are written to do whatever is required for the plugin
' they are called by name from the script and can have a maximum of three parameters  
Public Sub Params0
	Return 0
End Sub

Public Sub Params1(p1) 
	Return p1
End Sub

Public Sub Params2(p1, p2) 
	Return p1 & "," & p2
End Sub

Public Sub Params3(p1, p2, p3) 
	Return p1 & "," & p2 & "," & p3
End Sub

#End Region 

#Region Subs defined by the host program that are called from the Script module

' called when the script ended for whatever reason
' in this demo we just signal error or OK to the user
Sub Ended(error, errordata)
	If error<> "" Then
		Msgbox(errordata,"Script Error")
		ret = False
	Else	
		Msgbox("OK", "Script Ended")
		ret = True
	End If
	Return ret
End Sub

' called when the script called MsgBox(...) or Print ...
' in this demo we just display a message box to the user
Sub ShowMessage(msg, title)
	Msgbox(msg, title)
End Sub

#End Region

#Region Subs defined by the host program used for data transfer between script and host

' these Subs control data transfer to/from the plugin
' the array/variable is specified by name from the script
' you could add a callback into the main program to indicate a change
' you need to edit these to match the shared global variables
' it is done like this because Basic4ppc presently cannot indirectly access globals
' if it could this would be a lot simpler - Script.DataVariable = Global(HostArrayName)


Public Sub GetArray (HostArrayName)
	Select StrToLower(HostArrayName)
		Case "array0"
			Script.DataArray() = Array0()
		Case "array1"
			Script.DataArray() = Array1()
		Case "array2"
			Script.DataArray() = Array2()
		Case "array3"
			Script.DataArray() = Array3()
	End Select
End Sub

Public Sub SetArray(HostArrayName)
	Select StrToLower(HostArrayName)
		Case "array0"
			Array0() = Script.DataArray()
		Case "array1"
			Array0() = Script.DataArray()
		Case "array2"
			Array0() = Script.DataArray()
		Case "array3"
			Array0() = Script.DataArray()
	End Select
End Sub

Public Sub GetVar(HostVariableName)
	Select StrToLower(HostVariableName)
		Case "var0"
			Script.DataVariable = Var0
		Case "var1"
			Script.DataVariable = Var1
		Case "var2"
			Script.DataVariable = Var2
		Case "var3"
			Script.DataVariable = Var3
	End Select
End Sub

Public Sub SetVar(HostVariableName)
	Select StrToLower(HostVariableName)
		Case "var0"
			Var0 = Script.DataVariable
		Case "var1"
			Var1 = Script.DataVariable
		Case "var2"
			Var2 = Script.DataVariable
		Case "var3"
			Var3 = Script.DataVariable
	End Select
End Sub

#End Region 
